/*******************************************************************************
* File Name: TP4.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TP4.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        TP4_PC =   (TP4_PC & \
                                (uint32)(~(uint32)(TP4_DRIVE_MODE_IND_MASK << (TP4_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (TP4_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: TP4_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void TP4_Write(uint8 value) 
{
    uint8 drVal = (uint8)(TP4_DR & (uint8)(~TP4_MASK));
    drVal = (drVal | ((uint8)(value << TP4_SHIFT) & TP4_MASK));
    TP4_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: TP4_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  TP4_DM_STRONG     Strong Drive 
*  TP4_DM_OD_HI      Open Drain, Drives High 
*  TP4_DM_OD_LO      Open Drain, Drives Low 
*  TP4_DM_RES_UP     Resistive Pull Up 
*  TP4_DM_RES_DWN    Resistive Pull Down 
*  TP4_DM_RES_UPDWN  Resistive Pull Up/Down 
*  TP4_DM_DIG_HIZ    High Impedance Digital 
*  TP4_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void TP4_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(TP4__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: TP4_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TP4_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TP4_Read(void) 
{
    return (uint8)((TP4_PS & TP4_MASK) >> TP4_SHIFT);
}


/*******************************************************************************
* Function Name: TP4_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TP4_ReadDataReg(void) 
{
    return (uint8)((TP4_DR & TP4_MASK) >> TP4_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TP4_INTSTAT) 

    /*******************************************************************************
    * Function Name: TP4_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TP4_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(TP4_INTSTAT & TP4_MASK);
		TP4_INTSTAT = maskedStatus;
        return maskedStatus >> TP4_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
